;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "orgit-forge" "20251101.2141"
  "Org links to Forge issue buffers."
  '((emacs  "29.1")
    (compat "30.1")
    (forge  "0.6")
    (magit  "4.4")
    (org    "9.7")
    (orgit  "2.1"))
  :url "https://github.com/magit/orgit-forge"
  :commit "964a81d1e4e95a61e6304237172889b222fca845"
  :revdesc "964a81d1e4e9"
  :keywords '("hypermedia" "vc")
  :authors '(("Jonas Bernoulli" . "emacs.orgit-forge@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.orgit-forge@jonas.bernoulli.dev")))
